@@ -1,8 +1,6 @@
 package Music::Intervals::Ratios;
-$Music::Intervals::Ratios::VERSION = '0.0502';
-BEGIN {
-  $Music::Intervals::Ratios::AUTHORITY = 'cpan:GENE';
-}
+$Music::Intervals::Ratios::VERSION = '0.0503';
+our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 
@@ -1823,7 +1821,7 @@ Music::Intervals::Ratios
 
 =head1 VERSION
 
-version 0.0502
+version 0.0503
 
 =head1 AUTHOR
 
@@ -1831,7 +1829,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Gene Boggs.
+This software is copyright (c) 2019 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
